#ifndef __CONFIG_H__
#define __CONFIG_H__

/**
 * File Name  : config.h
 *
 * Description: GConf handling functions
 */

/*
 * This file is part of sysd.
 *
 * sysd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * sysd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Copyright (C) 2008 iRex Technologies B.V.
 * All rights reserved.
 */

//----------------------------------------------------------------------------
// Include Files
//----------------------------------------------------------------------------

G_BEGIN_DECLS

#include <hal.h>


//----------------------------------------------------------------------------
// Definitions
//---------------------------------------------------------------------------- 

#define KEYS_EREADER       "/apps/er"
#define KEYS_NM            "/system/networking/connections"

#define INI_FILE           MOUNTPOINT_CARD "/System/dr.ini"
#define ERCONFTOOL_EXPORT  "erconftool -c " INI_FILE " -e " KEYS_NM " -e " KEYS_EREADER
#define ERCONFTOOL_IMPORT  "erconftool -c " INI_FILE " -i " KEYS_NM " -i " KEYS_EREADER
#define ERCONFTOOL_DELETE  "erconftool -d " KEYS_NM                    \
                                     " -d " KEYS_EREADER "/private"    \
                                     " -d " KEYS_EREADER "/conn_wifi " \
                                     " -d " KEYS_EREADER "/conn_blue"


//----------------------------------------------------------------------------
// Forward Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Type Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Global Constants
//----------------------------------------------------------------------------


//============================================================================
// Public Functions
//============================================================================

/**---------------------------------------------------------------------------
 *
 * Name :  conf_set_services
 *
 * @brief  Initialize configuration
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void conf_set_services(void);

/**---------------------------------------------------------------------------
 *
 * Name :  conf_get_first_boot
 *
 * @brief  Run specials when this is the first boot of the device
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
gboolean conf_get_first_boot(void);

/**---------------------------------------------------------------------------
 *
 * Name :  conf_set_flightmode
 *
 * @brief  Run specials when this is the first boot of the device
 *
 * @param  [in] is_enabled - TRUE  flightmode enabled, no connectivity allowed
 *                           FALSE flightmode disabled, connectivity allowed
 *
 * @return TRUE =ok, FALSE = error
 *
 *--------------------------------------------------------------------------*/
gboolean conf_set_flightmode(gboolean is_enabled);

/**---------------------------------------------------------------------------
 *
 * Name :  conf_disabled_sensor_lock
 *
 * @brief  Read sensor lock settings from registry
 *         and set statusbar icon accordingly.
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void conf_disabled_sensor_lock(void);

void conf_set_first_boot(gboolean first_boot);
gboolean conf_is_multi_language(void);

G_END_DECLS

#endif /* __CONFIG_H__ */
