#ifndef __HAL_H__
#define __HAL_H__

/**
 * File Name  : hal.h
 *
 * Description: The HAL Hardware Abstraction functions
 */

/*
 * This file is part of sysd.
 *
 * sysd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * sysd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Copyright (C) 2008 iRex Technologies B.V.
 * All rights reserved.
 *
 * Parts used from halevt, Copyright (C) 2007  Patrice Dumas <pertusus at free dot fr>
 */


//----------------------------------------------------------------------------
// Include Files
//----------------------------------------------------------------------------

#include <hal/libhal.h>
#include <devicelist.h>


G_BEGIN_DECLS


//----------------------------------------------------------------------------
// Definitions
//---------------------------------------------------------------------------- 

#define MOUNTPOINT_CARD   "/media/mmcblk0p1"
#define MOUNT_OPTIONS     "iocharset=iso8859-1,utf8,noatime"


//----------------------------------------------------------------------------
// Forward Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Type Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Global Constants
//----------------------------------------------------------------------------


//============================================================================
// Public Functions
//============================================================================

/**---------------------------------------------------------------------------
 *
 * Name :  hal_set_services
 *
 * @brief  Setup HAL context and set callbacks for hal events
 *
 * @param  --
 *
 * @return TRUE if successfully set up, FALSE otherwise
 *
 *--------------------------------------------------------------------------*/
gboolean hal_set_services(void);

/**---------------------------------------------------------------------------
 *
 * Name :  hal_add_devices
 *
 * @brief  Scan HAL for available devices, run init and add to devicelist
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void hal_add_devices(void);

/**---------------------------------------------------------------------------
 *
 * Name :  hal_check_dbus_error
 *
 * @brief  Print and reset a dbus error
 *
 * @param  error Pointer to DBusError, memory is freed when set
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void hal_check_dbus_error(DBusError *error);

/**---------------------------------------------------------------------------
 *
 * Name :  hal_device_print
 *
 * @brief  Print a device to stdout, useful for debugging
 *
 * @param  udi Unique Device Id
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void hal_device_print(const char *udi);

/**---------------------------------------------------------------------------
 *
 * Name :  hal_get_iterator_value
 *
 * @brief  Return the value of iterator from Hal properties
 *
 * @param  type LibHalPropertyType type of property
 * @param  iter LibHalPropertySetIterator iterator
 *
 * @return value array
 *
 *--------------------------------------------------------------------------*/
char **hal_get_iterator_value(const LibHalPropertyType type, LibHalPropertySetIterator *iter);

/**---------------------------------------------------------------------------
 *
 * Name :  hal_property_value
 *
 * @brief  Return the value of Hal property 
 *
 * @param  key 
 * @param  udi Unique Device Id
 * @param  device hal_device 
 *
 * @return value array
 *
 *--------------------------------------------------------------------------*/
char **hal_property_value(const char *key, const char *udi, const hal_device *device);

gchar *hal_get_mountpoint_device(void);
void hal_remount_all_volumes(gpointer callback_function, gpointer user_data);
void hal_unmount_all_volumes(gpointer callback_function, gpointer user_data);
void hal_report_mounted_volumes(const char *ipc_service);


G_END_DECLS

#endif /* __HAL_H__ */
