#ifndef __WACOM_H__
#define __WACOM_H__

/**
 * File Name  : wacom.h
 *
 * Description: Wacom tables functions
 */

/*
 * This file is part of sysd.
 *
 * sysd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * sysd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Copyright (C) 2008 iRex Technologies B.V.
 * All rights reserved.
 */

//----------------------------------------------------------------------------
// Include Files
//----------------------------------------------------------------------------


G_BEGIN_DECLS


//----------------------------------------------------------------------------
// Definitions
//---------------------------------------------------------------------------- 


//----------------------------------------------------------------------------
// Forward Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Type Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Global Constants
//----------------------------------------------------------------------------


//============================================================================
// Public Functions
//============================================================================

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_scan_high
 *
 * @brief  Set Wacom tablet scanning to high accuracy, increasing power usage
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void wacom_scan_high(void);

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_scan_normal
 *
 * @brief  Normal Wacom tablet scanning, descreasing accuracy and preserving power
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void wacom_scan_normal(void);

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_resume
 *
 * @brief  Enable Wacom tablet, return to normal scanning
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void wacom_resume(void);

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_tilt_correction_enable
 *
 * @brief  Enable/Disable Hardware Tilt Correction algorithm
 *
 * @param  tilt_enable TRUE to enable correction, FALSE to disable it
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void wacom_tilt_correction_enable(gboolean tilt_enable);

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_suspend
 *
 * @brief  Suspend Wacom tablet, wakes up when pen detected
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void wacom_suspend(void);

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_enable
 *
 * @brief  Enable Wacom tablet
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void wacom_enable(void);

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_disable
 *
 * @brief  Disable Wacom tablet. No scanning at all.
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void wacom_disable(void);

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_reset
 *
 * @brief  Reset Wacom tablet by toggling hardware reset line.
 *
 * @param  --
 *
 * @return --
 *
 *--------------------------------------------------------------------------*/
void wacom_reset();

/**---------------------------------------------------------------------------
 *
 * Name :  wacom_is_enabled
 *
 * @brief  Query if Wacom tablet is enabled
 *
 * @param  --
 *
 * @return TRUE when Wacom tablet is enabled, FALSE otherwise
 *
 *--------------------------------------------------------------------------*/
gboolean wacom_is_enabled(void);

G_END_DECLS

#endif /* __WACOM_H__*/
