/*
 * File Name: sysclient.c
 */

/*
 * This file is part of sysd.
 *
 * sysd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * sysd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Copyright (C) 2008 iRex Technologies B.V.
 * All rights reserved.
 */

//----------------------------------------------------------------------------
// Include Files
//----------------------------------------------------------------------------

#include "config.h"

// system include files, between < >
#include <glib.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

// ereader include files, between < >
#include <liberipc/eripc.h>
#include <liberipc/eripc_support.h>

// local include files, between " "
#include "log.h"


//----------------------------------------------------------------------------
// Type Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Global Constants
//----------------------------------------------------------------------------

#define DBUS_APPL_NAME       "sysclient"
#define DBUS_SERVICE         "com.irexnet."  DBUS_APPL_NAME
#define DBUS_PATH            "/com/irexnet/" DBUS_APPL_NAME
#define DBUS_INTERFACE       "com.irexnet."  DBUS_APPL_NAME

#define DBUS_SERVICE_SYSD    "com.irexnet.sysd"
#define DBUS_SERVICE_CTB     "com.irexnet.ctb"
#define DBUS_SERVICE_POPUPMENU "com.irexnet.popupmenu"
     
//----------------------------------------------------------------------------
// Static Variables
//----------------------------------------------------------------------------

static eripc_client_context_t *eripcClient = NULL;


//============================================================================
// Local Function Definition
//============================================================================

static void usage(const char *argv_0);


//============================================================================
// Functions Implementation
//============================================================================

int main(int argc, char *argv[])
{
    if (argc <= 1)
    {
        usage(argv[0]);
        return 1;
    }
    
    eripcClient = eripc_client_context_new(
                    DBUS_APPL_NAME,
                    "1.0",
                    DBUS_SERVICE,
                    DBUS_PATH,
                    DBUS_INTERFACE,
                    NULL);
    
    if (eripcClient == NULL)
    {
        printf("Cannot connect to DBUS, make sure DISPLAY environment variable is set.\n\n");
        return 1;
    }
    
    if (strcmp(argv[1], "startTask") == 0)
    {
        if (argc == 6)
        {
            LOGPRINTF("Calling %s %s...", argv[1], argv[2]);
            
            eripc_send_varargs(eripcClient->context, 
                               NULL,
                               NULL,
                               ERIPC_BUS_SESSION,
                               DBUS_SERVICE_SYSD,
                               argv[1], 
                               ERIPC_TYPE_STRING, argv[2],
                               ERIPC_TYPE_STRING, argv[3],
                               ERIPC_TYPE_STRING, argv[4],
                               ERIPC_TYPE_STRING, argv[5],
                               ERIPC_TYPE_INVALID);
        }
        else
        {
            WARNPRINTF("Invalid args for %s", argv[1]);
        }
    }
    else if ((strcmp(argv[1], "menuRequestPopup") == 0)
          || (strcmp(argv[1], "stopTask")         == 0))
    {
        if (argc == 3)
        {
            LOGPRINTF("Calling %s %s...", argv[1], argv[2]);
            
            eripc_send_varargs(eripcClient->context,
                               NULL,
                               NULL,
                               ERIPC_BUS_SESSION,
                               DBUS_SERVICE_SYSD,
                               argv[1], 
                               ERIPC_TYPE_STRING, argv[2],
                               ERIPC_TYPE_INVALID);
        }
        else
        {
            WARNPRINTF("Invalid args for %s", argv[1]);
        }
    }
    else if (strcmp(argv[1], "gotoHome") == 0)
    {
        if (argc == 2)
        {
            LOGPRINTF("Calling %s...", argv[1]);
            
            eripc_send_varargs(eripcClient->context,
                               NULL,
                               NULL,
                               ERIPC_BUS_SESSION,
                               DBUS_SERVICE_SYSD,
                               "menuItemActivated", 
                               ERIPC_TYPE_STRING, "desktop", /* item */
                               ERIPC_TYPE_STRING, "general", /* group */
                               ERIPC_TYPE_STRING, "", /* menu */
                               ERIPC_TYPE_STRING, "", /* state */
                               ERIPC_TYPE_INVALID);
        }
        else
        {
            WARNPRINTF("Invalid args for %s", argv[1]);
        }
    }
    else if ((strcmp(argv[1], "sysCardUnmount") == 0)
          || (strcmp(argv[1], "sysShutdown")    == 0)
          || (strcmp(argv[1], "sysStandby")     == 0))
    {
        if (argc == 2)
        {
            LOGPRINTF("Calling %s...", argv[1]);
            
            eripc_send_varargs(eripcClient->context,
                               NULL,
                               NULL,
                               ERIPC_BUS_SESSION,
                               DBUS_SERVICE_SYSD,
                               argv[1], 
                               ERIPC_TYPE_INVALID);
        }
        else
        {
            WARNPRINTF("Invalid args for %s", argv[1]);
        }
    }
    else if ((strcmp(argv[1], "sysCardMount")  == 0))
    {
        if (argc == 2)
        {
            LOGPRINTF("Calling %s...", argv[1]);
            
            eripc_send_varargs(eripcClient->context,
                               NULL,
                               NULL,
                               ERIPC_BUS_SESSION,
                               DBUS_SERVICE_SYSD,
                               argv[1], 
                               ERIPC_TYPE_BOOL, TRUE,
                               ERIPC_TYPE_INVALID);
        }
        else
        {
            WARNPRINTF("Invalid args for %s", argv[1]);
        }
    }
    else if ((strcmp(argv[1], "ctbRefresh") == 0))
    {
        LOGPRINTF("Calling %s...", argv[1]);
        
        eripc_send_varargs(eripcClient->context,
                      NULL,
                      NULL,
                      ERIPC_BUS_SESSION,
                      DBUS_SERVICE_CTB,
                      "filesystemChanged", 
                      ERIPC_TYPE_INVALID);
    }
    else if ((strcmp(argv[1], "listTasks") == 0))
    {
        LOGPRINTF("Calling %s...", argv[1]);
        
        eripc_send_varargs(eripcClient->context,
                      NULL,
                      NULL,
                      ERIPC_BUS_SESSION,
                      DBUS_SERVICE_SYSD,
                      "testingListTasks", 
                      ERIPC_TYPE_INVALID);
    }
    else if ((strcmp(argv[1], "listMenu") == 0))
    {
        LOGPRINTF("Calling %s...", argv[1]);
        
        eripc_send_varargs(eripcClient->context,
                      NULL,
                      NULL,
                      ERIPC_BUS_SESSION,
                      DBUS_SERVICE_POPUPMENU,
                      "testingListMenuItems", 
                      ERIPC_TYPE_INVALID);
    }
    else
    {
        usage(argv[0]);
    }
    return 1;
}


static void usage(const char *argv_0)
{
    static const char *usage_text = 
        "Usage:\n"
        "    %s <command> [<arguments>]\n"
        "\n"
        "Commands and aguments:\n"
        "    startTask\t- start a new task/application\n"
        "    \tcommand_line\tstring, full path to application with arguments\n"
        "    \tworking_dir\tstring, current working directory\n"
        "    \tlabel\tstring, text label shown under icon in popup menu\n"
        "    \timage\tstring, full path to icon shown in popup menu (png, 60x60 pixels)\n"
        "    stopTask\t- stop a running task/applciation\n"
        "    \tcommand_line\tstring, full path to application with arguments\n"
        "    listTasks\t- show lists of running tasks, windows and processes\n"
        "    menuRequestPopup\t- show/hide the popupmenu\n"
        "    \tstate\tstring, \"show\" | \"hide\" | \"toggle\"\n"
        "    gotoHome\t- activate ctb desktop/home\n"
        "    sysCardMount\t- mount the SD card(s)\n"
        "    sysCardUnmount\t- unmount the SD card(s)\n"
        "    sysShutdown\t- graciously shut down the system\n"
        "    sysStandby\t- enter standby mode\n"
        "    ctbRefresh\t- refresh ctb fileview from database\n"
        "    listMenu\t- show all entries in popupmenu\n"
        "\n";
 
    printf(usage_text, argv_0);

    exit(1);
}
