/*
 * File Name:  bert.c
 */

/**
 * Copyright (C) 2009 iRex Technologies B.V.
 * All rights reserved.
 */

#include "config.h"

#define LOGGING_ON 1

// system include files, between < >
#include <glib.h>
#include <gtk/gtk.h>
#include <signal.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include <liberipc/eripc.h>
#include <liberipc/eripc_support.h>

#include "log.h"

#define DBUS_APPL_NAME       "bert"
#define DBUS_SERVICE         "com.irexnet." DBUS_APPL_NAME
#define DBUS_PATH            "/com/irexnet/" DBUS_APPL_NAME
#define DBUS_INTERFACE       "com.irexnet." DBUS_APPL_NAME

#define DBUS_SERVICE_ERNIE   "com.irexnet.ernie"

#define MAXCOUNT 100
#define DELAY_MS 100

int activated_handler = -1;
static eripc_client_context_t *eripcClient = NULL;


static void on_ping (eripc_context_t *context, const eripc_event_info_t *info, void *user_data);
static void on_pong (eripc_context_t *context, const eripc_event_info_t *info, gpointer data);

static eripc_callback_function_t service_functions[] = {
        { on_ping,         "callbert",           NULL,             0 },
        { NULL }  // end of list
    };


gboolean ipc_set_services()
{
    eripcClient = eripc_client_context_new(
                    DBUS_APPL_NAME,
                    "1.0",
                    DBUS_SERVICE,
                    DBUS_PATH,
                    DBUS_INTERFACE,
                    service_functions);

    return TRUE;
}


void ipc_unset_services()
{
    eripc_client_context_free(eripcClient, service_functions);
}


void ipc_send_ping(void *callback_handler, 
                   void *callback_data)
{
    eripc_error_t retval;

    retval = eripc_send_varargs(eripcClient->context, 
                               callback_handler,
                               callback_data,
                               ERIPC_BUS_SESSION,
                               DBUS_SERVICE_ERNIE,
                               "callernie",
                               ERIPC_TYPE_STRING, "greets from bert",
                               ERIPC_TYPE_INVALID);
    
    if (retval != ERIPC_ERROR_SUCCESS) 
    {
        ERRORPRINTF("Error launching eripc handler: %s", eripc_error_string(retval));
        return;
    }

    LOGPRINTF("Sent ping");
}


static void on_pong (eripc_context_t *context,
                    const eripc_event_info_t *info,
                    gpointer data)
{
    if (info->event_type != ERIPC_EVENT_REPLY)
    {
        WARNPRINTF("invalid event: %d", info->event_type);
    }
    else
    {
        LOGPRINTF("Pong from ERNIE [%d]", (gint) data);
    }
}


static void on_ping (eripc_context_t *context, 
                    const eripc_event_info_t *info, 
                    void *user_data)
{
    gint32 wait = g_random_int_range(1000, 100*1000);
    
    LOGPRINTF("Ping from ERNIE, return Pong in [%d] ms", wait/1000);
    g_usleep(wait);
    
    eripc_reply_bool(context, info->message_id, TRUE);
}


static gboolean on_second(gpointer data)
{
    static gint count = 0;
    
    ipc_send_ping(on_pong, (gpointer)count++);
    
    if (count>MAXCOUNT)
    {
        gtk_main_quit();
        // don't call again
        return FALSE;
    }
    
    return TRUE;
}


int main(int argc, char *argv[])
{
    // init gdk (for windowing)
    g_type_init();
    gtk_init(&argc, &argv);
    
    LOGPRINTF("Starting...");

    // prepare IPC, system (micro) and display
    ipc_set_services();
        
    LOGPRINTF("Running...");
    
    gint32 interval = g_random_int_range(100, 200);
    g_timeout_add(interval, on_second, NULL);
    
    // run the main loop
    LOGPRINTF("before gtk_main");
    gtk_main();
    LOGPRINTF("after gtk_main");
    
    ipc_unset_services();    
    
    LOGPRINTF("...Exit");
    
    return 0;
}
