/*
 * File Name: displaytest.c
 */

/*
 * This file is part of sysd.
 *
 * sysd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * sysd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Copyright (C) 2008 iRex Technologies B.V.
 * All rights reserved.
 */

//----------------------------------------------------------------------------
// Include Files
//----------------------------------------------------------------------------

#include "config.h"

// system include files, between < >
#include <stdio.h>
#include <unistd.h>
#include <string.h> 
#include <arpa/inet.h>

// ereader include files, between < >

// local include files, between " "
#include "delta.h"
#include "log.h"


//----------------------------------------------------------------------------
// Type Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Global Constants
//----------------------------------------------------------------------------

#define DMPORT      50555
#define DMSERVER    "127.0.0.1"
#define MESSAGEFULL "0,0,0,768,1024,0,1,1,displaytest"


//----------------------------------------------------------------------------
// Static Variables
//----------------------------------------------------------------------------


//============================================================================
// Local Function Definitions
//============================================================================

void displayHelp(void);


//============================================================================
// Functions Implementation
//============================================================================

void displayHelp()
{
    printf("Usage: displaytest -<option> <argument>\n");
    printf("  no arguments : send full display update message to local host\n");
    printf("  -m <formatted display string>  : message to send (x,y,width,height,is_window,window_type,widget_type)\n");
    printf("  -d <dotted decimal ip address> : destination IP address\n");
    printf("  -h : display this message\n");
}

int main(int argc, char **argv)
{
    char    destination[INET_ADDRSTRLEN] = DMSERVER;
    char    message[256]                 = MESSAGEFULL;
    char    msg[256]                     = {0};
    struct  sockaddr_in server_addr      = {0};
    int     nArg = 1;
    int     fd   = 0;

    // work our way through all possible options
    while (nArg < argc)
    {
        if (argv[nArg][0] == '-')
        {
            switch (argv[nArg][1])
            {
            case 'h':
                displayHelp();
                return 0;
                break;

            case 'd':
                // What address ?
                if (++nArg >= argc)
                {
                    // not enough arguments supplied
                    ERRORPRINTF("Supply a dotted decimal IP address after option -d");
                    displayHelp();
                    return -1;
                }
                else
                {
                    strncpy(destination, argv[nArg], INET_ADDRSTRLEN);
                    nArg++;
                }
                break;

            case 'm':
                if (++nArg >= argc)
                {
                    // not enough arguments supplied
                    ERRORPRINTF("Supply a message string after option -m");
                    displayHelp();
                    return -1;
                }
                else
                {
                    strncpy(message, argv[nArg], sizeof(message));
                    nArg++;
                }
                break;

            default:
                ERRORPRINTF("Option %s not known", argv[nArg]);
                displayHelp();
                return -1;
            }
        }
        else
        {
            ERRORPRINTF("Argument supplied not proceded by option");
            displayHelp();
            return -1;
        }
    }

    // create and bind socket
    fd = socket(PF_INET, SOCK_DGRAM, 0);
    server_addr.sin_family = AF_INET;
    server_addr.sin_port = htons(DMPORT);
    server_addr.sin_addr.s_addr = inet_addr(destination);
    memset(server_addr.sin_zero, '\0', sizeof(server_addr.sin_zero));
    
    // send display update message
    snprintf(msg, sizeof(msg)-1, "!I,%s", message);
    sendto(fd, msg, strlen(msg), 0, (struct sockaddr*) &server_addr, sizeof(server_addr));

    LOGPRINTF("Sent message: %s to %s", msg, destination);
    
    close(fd);
    
    return 0;
}
