/*
 * File Name: wmtest.c
 */

/*
 * This file is part of sysd.
 *
 * sysd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * sysd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Copyright (C) 2008 iRex Technologies B.V.
 * All rights reserved.
 */

//----------------------------------------------------------------------------
// Include Files
//----------------------------------------------------------------------------

#include "config.h"

// system include files, between < >
#include <glib.h>
#include <gtk/gtk.h>
#include <gdk/gdkx.h>
#include <stdio.h>

//#include <libmb/mbdotdesktop.h>
#include <libmb/mbutil.h>

#include "log.h"

#define RETURN_NONE_IF_NULL(p) if ((p) == '\0') return None; 

static Window single_instance_get_window(Display *dpy, const char *bin_name);


// main function
int main(int argc, char *argv[])
{
    LOGPRINTF("entry");

    Window win_found;
    Display *display;
    
    g_type_init();
    gtk_init(&argc, &argv);

    LOGPRINTF("default screen = %d", gdk_x11_get_default_screen());
    
    LOGPRINTF("get display");
    display = gdk_x11_get_default_xdisplay();
    LOGPRINTF("display = %p", display);
    
    LOGPRINTF("get window: %s", argv[1]);
    win_found = single_instance_get_window (display, argv[1]);

    if (win_found != None) 
    {
        LOGPRINTF("window found and activated!");
//        mb_util_window_activate(display, win_found);
    }
    else
    {
        LOGPRINTF("window not found");
    }

    return 0;
}


static Window single_instance_get_window(Display *dpy, const char *bin_name)
{
    /* XXX Should really set this on init rather than every time */
    Atom atom_exec_map = XInternAtom(dpy, "_NET_CLIENT_LIST", False);
    LOGPRINTF("entry");

    Atom type;
    int format;
    unsigned char *data = NULL;
    unsigned long n_items, bytes_after;
    int result;
    int i;
    XClassHint hint;
    
    LOGPRINTF("enter");

    Atom atom_net_get_active = XInternAtom(dpy, "_NET_ACTIVE_WINDOW", False);
    
    result = XGetWindowProperty(dpy, RootWindow(dpy, DefaultScreen(dpy)), 
                                atom_net_get_active,
                                0, 10000L,
                                False, XA_WINDOW,
                                &type, &format, &n_items,
                                &bytes_after, (unsigned char **)&data);
    
    
    if (result != Success || data == NULL || n_items == 0)
    {
        if (data) XFree(data);
        LOGPRINTF("failed to get windowproperty 1. result = %d, data = %p, items = %ld", result, data, n_items);
        return None;
    }

    if (XGetClassHint(dpy, ((Window*)data)[0], &hint))
    {
        LOGPRINTF("Active window %s, %s", hint.res_name, hint.res_class);
    }

    result = XGetWindowProperty(dpy, RootWindow(dpy, DefaultScreen(dpy)), 
                                atom_exec_map,
                                0, 10000L,
                                False, XA_WINDOW,
                                &type, &format, &n_items,
                                &bytes_after, (unsigned char **)&data);

    if (result != Success || data == NULL || n_items == 0)
    {
        if (data) XFree(data);
        LOGPRINTF("failed to get windowproperty 2. result = %d, data = %p, items = %ld", result, data, n_items);
        return None;
    }

    for (i = 0; i < n_items; i++)
    {
        if (XGetClassHint(dpy, ((Window*)data)[i], &hint))
        {
            LOGPRINTF("Window [%d] window:%d, class: %s, name: %s", i, (guint) ((Window*)data)[i], hint.res_name, hint.res_class);
            
            if (strcmp(hint.res_name, bin_name) == 0)
            {
                LOGPRINTF("Found and activated %s",bin_name);
//                mb_util_window_activate(dpy, ((Window*)data)[i]);
                
  Atom atom_net_active = XInternAtom(dpy, "_NET_ACTIVE_WINDOW", False);
  XEvent ev;

  memset(&ev, 0, sizeof ev);
  ev.xclient.type = ClientMessage;
  ev.xclient.window = ((Window*)data)[i];
  ev.xclient.message_type = atom_net_active;
  ev.xclient.format = 32;

  ev.xclient.data.l[0] = 1; 
  int retval;
  retval = XSendEvent(dpy, RootWindow(dpy, DefaultScreen(dpy)), False, SubstructureRedirectMask, &ev);
                
  LOGPRINTF("XSendEvent returned %d", retval);
                
                return ((Window*)data)[i];
            }
        }
    }

    XFree (data);

    return None;
}
